@@ -1,9 +1,10 @@
-from dagster.core.utils import check_dagster_package_version
+from dagster._core.utils import check_dagster_package_version
 
 from .event_log import MySQLEventLogStorage
 from .run_storage import MySQLRunStorage
 from .schedule_storage import MySQLScheduleStorage
+from .storage import DagsterMySQLStorage
 from .version import __version__
 
 check_dagster_package_version("dagster-mysql", __version__)
-__all__ = ["MySQLEventLogStorage", "MySQLRunStorage", "MySQLScheduleStorage"]
+__all__ = ["DagsterMySQLStorage", "MySQLEventLogStorage", "MySQLRunStorage", "MySQLScheduleStorage"]
