@@ -1,4 +1,4 @@
-from typing import Dict
+from typing import Mapping
 
 import sqlalchemy as db
 from packaging.version import parse
@@ -30,6 +30,7 @@ from ..utils import (
 )
 
 MINIMUM_MYSQL_BUCKET_VERSION = "8.0.0"
+MINIMUM_MYSQL_INTERSECT_VERSION = "8.0.31"
 
 
 class MySQLRunStorage(SqlRunStorage, ConfigurableClass):
@@ -156,6 +157,10 @@ class MySQLRunStorage(SqlRunStorage, ConfigurableClass):
 
         return parse(self._mysql_version) >= parse(MINIMUM_MYSQL_BUCKET_VERSION)
 
+    @property
+    def supports_intersect(self):
+        return parse(self._mysql_version) >= parse(MINIMUM_MYSQL_INTERSECT_VERSION)
+
     def add_daemon_heartbeat(self, daemon_heartbeat):
         with self.connect() as conn:
             conn.execute(
@@ -173,8 +178,8 @@ class MySQLRunStorage(SqlRunStorage, ConfigurableClass):
                 )
             )
 
-    def kvs_set(self, pairs: Dict[str, str]) -> None:
-        check.dict_param(pairs, "pairs", key_type=str, value_type=str)
+    def kvs_set(self, pairs: Mapping[str, str]) -> None:
+        check.mapping_param(pairs, "pairs", key_type=str, value_type=str)
         db_values = [{"key": k, "value": v} for k, v in pairs.items()]
 
         with self.connect() as conn:
