@@ -1,22 +1,29 @@
 import pendulum
 import sqlalchemy as db
+from packaging.version import parse
 
-from dagster import check
-from dagster.core.storage.schedules import ScheduleStorageSqlMetadata, SqlScheduleStorage
-from dagster.core.storage.schedules.schema import InstigatorsTable
-from dagster.core.storage.sql import create_engine, run_alembic_upgrade, stamp_alembic_rev
-from dagster.serdes import ConfigurableClass, ConfigurableClassData, serialize_dagster_namedtuple
+import dagster._check as check
+from dagster._core.storage.config import mysql_config
+from dagster._core.storage.schedules import ScheduleStorageSqlMetadata, SqlScheduleStorage
+from dagster._core.storage.schedules.schema import InstigatorsTable
+from dagster._core.storage.sql import (
+    check_alembic_revision,
+    create_engine,
+    run_alembic_upgrade,
+    stamp_alembic_rev,
+)
+from dagster._serdes import ConfigurableClass, ConfigurableClassData, serialize_dagster_namedtuple
 
 from ..utils import (
-    MYSQL_POOL_RECYCLE,
     create_mysql_connection,
     mysql_alembic_config,
-    mysql_config,
     mysql_url_from_config,
     retry_mysql_connection_fn,
     retry_mysql_creation_fn,
 )
 
+MINIMUM_MYSQL_BATCH_VERSION = "8.0.0"
+
 
 class MySQLScheduleStorage(SqlScheduleStorage, ConfigurableClass):
     """MySQL-backed run storage.
@@ -25,7 +32,7 @@ class MySQLScheduleStorage(SqlScheduleStorage, ConfigurableClass):
     ``dagit`` and ``dagster-graphql`` load, based on the values in the ``dagster.yaml`` file in
     ``$DAGSTER_HOME``. Configuration of this class should be done by setting values in that file.
 
-    .. literalinclude:: ../../../../../../examples/docs_snippets/docs_snippets/deploying/dagster-mysql.yaml
+    .. literalinclude:: ../../../../../../examples/docs_snippets/docs_snippets/deploying/dagster-mysql-legacy.yaml
        :caption: dagster.yaml
        :start-after: start_marker_schedules
        :end-before: end_marker_schedules
@@ -52,6 +59,8 @@ class MySQLScheduleStorage(SqlScheduleStorage, ConfigurableClass):
         if "jobs" not in table_names:
             retry_mysql_creation_fn(self._init_db)
 
+        self._mysql_version = self.get_server_version()
+
         super().__init__()
 
     def _init_db(self):
@@ -64,14 +73,14 @@ class MySQLScheduleStorage(SqlScheduleStorage, ConfigurableClass):
         self.migrate()
         self.optimize()
 
-    def optimize_for_dagit(self, statement_timeout):
+    def optimize_for_dagit(self, statement_timeout, pool_recycle):
         # When running in dagit, hold an open connection
         # https://github.com/dagster-io/dagster/issues/3719
         self._engine = create_engine(
             self.mysql_url,
             isolation_level="AUTOCOMMIT",
             pool_size=1,
-            pool_recycle=MYSQL_POOL_RECYCLE,
+            pool_recycle=pool_recycle,
         )
 
     @property
@@ -104,6 +113,20 @@ class MySQLScheduleStorage(SqlScheduleStorage, ConfigurableClass):
     def connect(self, run_id=None):  # pylint: disable=arguments-differ, unused-argument
         return create_mysql_connection(self._engine, __file__, "schedule")
 
+    @property
+    def supports_batch_queries(self):
+        if not self._mysql_version:
+            return False
+
+        return parse(self._mysql_version) >= parse(MINIMUM_MYSQL_BATCH_VERSION)
+
+    def get_server_version(self):
+        rows = self.execute("select version()")
+        if not rows:
+            return None
+
+        return rows[0][0]
+
     def upgrade(self):
         alembic_config = mysql_alembic_config(__file__)
         run_alembic_upgrade(alembic_config, self._engine)
@@ -126,3 +149,8 @@ class MySQLScheduleStorage(SqlScheduleStorage, ConfigurableClass):
                 update_timestamp=pendulum.now("UTC"),
             )
         )
+
+    def alembic_version(self):
+        alembic_config = mysql_alembic_config(__file__)
+        with self.connect() as conn:
+            return check_alembic_revision(alembic_config, conn)
